# gigman

A simple, no-nonsense gitignore manager written in Python

- add/remove templates (from [github/gitignore](https://github.com/github/gitignore))
- does not remove any previous data in your `.gitignore`

![demo](images/demo.gif)

## Install

```
pip install gigman
```

## Usage

```
gigman
```

- Type to filter
- Press enter to add/remove a template
- Ctrl-C to exit
